==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PH/ts/Arc2PH_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Arc2PH</name>
    <message>
        <location filename="../Arc2PH.js" line="+65"/>
        <source>Start point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>End point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Invalid height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Arc2PH.ui" line="+17"/>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Clockwise (Negative)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Arc2PHInit.js" line="+2"/>
        <source>2 Points and &amp;Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and height</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PH/ts/Arc2PH_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Arc2PH</name>
    <message>
        <location filename="../Arc2PH.js" line="+65"/>
        <source>Start point</source>
        <translation>起点</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>End point</source>
        <translation>终点</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Invalid height</source>
        <translation>无效高度</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation>两点为同一点</translation>
    </message>
    <message>
        <location filename="../Arc2PH.ui" line="+17"/>
        <source>Height:</source>
        <translation>高度：</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation>方向：</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation>逆时针（正向）</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Clockwise (Negative)</source>
        <translation>顺时针（负向）</translation>
    </message>
    <message>
        <location filename="../Arc2PHInit.js" line="+2"/>
        <source>2 Points and &amp;Height</source>
        <translation>两点和高度(&amp;H)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and height</source>
        <translation>以两点和高度画弧</translation>
    </message>
</context>
</TS>
